Package com.google.api.server.spi
Class ConfiguredObjectMapper
- java.lang.Object
-
- com.google.api.server.spi.ConfiguredObjectMapper
-
public class ConfiguredObjectMapper extends Object
A wrapper around anObjectMapperwith a frozen configuration. This exposes a subset ofObjectMappermethods, it doesn't allow modifications to configuration.The created ObjectMapper also automatically installs some modules that are common to SPI code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classConfiguredObjectMapper.BuilderA builder for constructingConfiguredObjectMapperinstances.
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ConfiguredObjectMapper.Builderbuilder()Constructs a newConfiguredObjectMapper.Builderfor creatingConfiguredObjectMapperinstances.com.fasterxml.jackson.databind.ObjectReaderreader()Returns an ObjectReader, this has an immutable configuration.com.fasterxml.jackson.databind.ObjectWriterwriter()Returns an ObjectWriter, this has an immutable configuration.
-
-
-
Method Detail
-
reader
public com.fasterxml.jackson.databind.ObjectReader reader()
Returns an ObjectReader, this has an immutable configuration.- Returns:
- a reader
-
writer
public com.fasterxml.jackson.databind.ObjectWriter writer()
Returns an ObjectWriter, this has an immutable configuration.- Returns:
- a writer
-
builder
public static ConfiguredObjectMapper.Builder builder()
Constructs a newConfiguredObjectMapper.Builderfor creatingConfiguredObjectMapperinstances.- Returns:
- a builder
-
-