Class EndpointMethod.ResolvedSignature

  • Enclosing class:
    EndpointMethod

    public class EndpointMethod.ResolvedSignature
    extends Object
    Adapter class to compare EndpointMethod instances based on their Java method signature rather than the actual method implementation. Comparisons are based on resolved types.

    This is a pure adapter class containing no state of its own, relying entirely on the state of the owning EndpointMethod object. All access to the owning object is made through qualified this calls to make dependencies as clear as possible.

    • Constructor Detail

      • ResolvedSignature

        public ResolvedSignature()
    • Method Detail

      • getSignatureName

        public String getSignatureName()
      • getSignatureParameterClasses

        public Class<?>[] getSignatureParameterClasses()
      • hashCode

        public int hashCode()
        Overrides:
        hashCode in class Object