Package com.google.api.server.spi
Class ObjectMapperUtil
- java.lang.Object
-
- com.google.api.server.spi.ObjectMapperUtil
-
public class ObjectMapperUtil extends Object
Utilities forObjectMapper.
-
-
Constructor Summary
Constructors Constructor Description ObjectMapperUtil()
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static com.fasterxml.jackson.databind.ObjectMappercreateStandardObjectMapper()Creates an Endpoints standard object mapper that allows unquoted field names and unknown properties.static com.fasterxml.jackson.databind.ObjectMappercreateStandardObjectMapper(ApiSerializationConfig config)Creates an Endpoints standard object mapper that allows unquoted field names and unknown properties.
-
-
-
Method Detail
-
createStandardObjectMapper
public static com.fasterxml.jackson.databind.ObjectMapper createStandardObjectMapper()
Creates an Endpoints standard object mapper that allows unquoted field names and unknown properties. Note on unknown properties: When Apiary FE supports a strict mode where properties are checked against the schema, BE can just ignore unknown properties. This way, FE does not need to filter out everything that the BE doesn't understand. Before that's done, a property name with a typo in it, for example, will just be ignored by the BE.
-
createStandardObjectMapper
public static com.fasterxml.jackson.databind.ObjectMapper createStandardObjectMapper(ApiSerializationConfig config)
Creates an Endpoints standard object mapper that allows unquoted field names and unknown properties. Note on unknown properties: When Apiary FE supports a strict mode where properties are checked against the schema, BE can just ignore unknown properties. This way, FE does not need to filter out everything that the BE doesn't understand. Before that's done, a property name with a typo in it, for example, will just be ignored by the BE.
-
-