Uses of Class
com.google.api.server.spi.ServiceException
-
-
Uses of ServiceException in com.google.api.server.spi
Methods in com.google.api.server.spi with type parameters of type ServiceException Modifier and Type Method Description static <T extends ServiceException>
TServiceException. withLogLevel(T exception, Level level)Methods in com.google.api.server.spi that throw ServiceException Modifier and Type Method Description ObjectSystemService. findService(String name)Finds a service object with thenameMethodSystemService. findServiceMethod(Object service, String methodName)Finds a method object with the givenmethodNameon theserviceobject.EndpointMethodSystemService. resolveService(String serviceName, String methodName)Finds a service object with theserviceNameornullif not found. -
Uses of ServiceException in com.google.api.server.spi.config
Methods in com.google.api.server.spi.config that throw ServiceException Modifier and Type Method Description UserAuthenticator. authenticate(javax.servlet.http.HttpServletRequest request)Authenticates the user fromrequest. -
Uses of ServiceException in com.google.api.server.spi.handlers
Methods in com.google.api.server.spi.handlers that throw ServiceException Modifier and Type Method Description protected ResultWriterEndpointsMethodHandler. createResultWriter(EndpointsContext context, ApiSerializationConfig serializationConfig)Override to customize the serialization of the response body -
Uses of ServiceException in com.google.api.server.spi.request
Methods in com.google.api.server.spi.request that throw ServiceException Modifier and Type Method Description protected Object[]ServletRequestParamReader. deserializeParams(com.fasterxml.jackson.databind.JsonNode node)Object[]ParamReader. read()Reads parameters in JSON into an Object array to be used to invoke an Endpoint method.Object[]RestServletRequestParamReader. read()Object[]ServletRequestParamReader. read() -
Uses of ServiceException in com.google.api.server.spi.response
Subclasses of ServiceException in com.google.api.server.spi.response Modifier and Type Class Description classBadRequestExceptionBad request exception that is mapped to a 400 response.classConflictExceptionConflict exception that is mapped to a 409 response.classForbiddenExceptionForbidden exception that is mapped to a 403 response.classInternalServerErrorExceptionInternal server exception that is mapped to a 500 response.classNotFoundExceptionNot found exception that is mapped to a 404 response.classServiceUnavailableExceptionService Unavailable response for the API, mapped to a HTTP 503 response.classUnauthorizedExceptionUnauthorized exception that is mapped to a 401 response.Methods in com.google.api.server.spi.response with parameters of type ServiceException Modifier and Type Method Description voidRestResponseResultWriter. writeError(ServiceException e)Writes an error in the expected form for JSON-REST: { "error": { "errors: [ { "domain: "global", "reason": "backendError", "message: "..." } ], "code": 503, "message": "..." } }voidResultWriter. writeError(ServiceException e)Writes an error response with the HTTP status code and JSON body of {"message": "<exception's message>"}.voidServletResponseResultWriter. writeError(ServiceException e)
-