Package com.google.api.server.spi.config
Class ApiConfigInconsistency.ListBuilder<T>
- java.lang.Object
-
- com.google.api.server.spi.config.ApiConfigInconsistency.ListBuilder<T>
-
- Enclosing class:
- ApiConfigInconsistency<T>
public static class ApiConfigInconsistency.ListBuilder<T> extends Object
Builder to build a list of inconsistency objects.
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description <T1 extends T>
ApiConfigInconsistency.ListBuilder<T>addAll(Iterable<ApiConfigInconsistency<T1>> inconsistencies)<T1 extends T>
ApiConfigInconsistency.ListBuilder<T>addIfInconsistent(String propertyName, T1 value1, T1 value2)Creates and adds an inconsistency object to the list iff the two given values are not equal.com.google.common.collect.ImmutableList<ApiConfigInconsistency<T>>build()
-
-
-
Method Detail
-
addIfInconsistent
public <T1 extends T> ApiConfigInconsistency.ListBuilder<T> addIfInconsistent(String propertyName, T1 value1, T1 value2)
Creates and adds an inconsistency object to the list iff the two given values are not equal.
-
addAll
public <T1 extends T> ApiConfigInconsistency.ListBuilder<T> addAll(Iterable<ApiConfigInconsistency<T1>> inconsistencies)
-
build
public com.google.common.collect.ImmutableList<ApiConfigInconsistency<T>> build()
-
-