Annotation Type ApiMethodCacheControl


  • @Retention(RUNTIME)
    @Target(METHOD)
    @Deprecated
    public @interface ApiMethodCacheControl
    Deprecated.
    ApiMethodCacheControl is deprecated and will be removed in a future version of Cloud Endpoints.
    Annotation for configuration of API method cache control.
    • Optional Element Summary

      Optional Elements 
      Modifier and Type Optional Element Description
      int maxAge
      Deprecated.
      Overrides the maximum age to cache responses from this method.
      boolean noCache
      Deprecated.
      Disables caching of this method.
    • Element Detail

      • noCache

        boolean noCache
        Deprecated.
        Disables caching of this method. The default value is true, so merely adding this annotation to your method config will disable caching for that method, unless you set this field to false.
        Default:
        true
      • maxAge

        int maxAge
        Deprecated.
        Overrides the maximum age to cache responses from this method.
        Default:
        0