Class ApiClassConfig.MethodConfigMap
- java.lang.Object
-
- java.util.AbstractMap<K,V>
-
- java.util.HashMap<K,V>
-
- java.util.LinkedHashMap<EndpointMethod,ApiMethodConfig>
-
- com.google.api.server.spi.config.model.ApiClassConfig.MethodConfigMap
-
- All Implemented Interfaces:
Serializable,Cloneable,Map<EndpointMethod,ApiMethodConfig>
- Enclosing class:
- ApiClassConfig
public static class ApiClassConfig.MethodConfigMap extends LinkedHashMap<EndpointMethod,ApiMethodConfig>
Mapof API methods for this API class.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object,V extends Object>
-
-
Constructor Summary
Constructors Modifier Constructor Description protectedMethodConfigMap(ApiClassConfig apiClassConfig)protectedMethodConfigMap(ApiClassConfig.MethodConfigMap original, ApiClassConfig apiClassConfig)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description protected ApiMethodConfigcreateMethodConfig(EndpointMethod method, TypeLoader typeLoader, ApiClassConfig apiClassConfig)Create the method configuration object.ApiClassConfiggetApiClassConfig()ApiMethodConfiggetOrCreate(EndpointMethod method)Gets the previously createdApiMethodConfiginstance for the given method, or creates a new one if it does not yet exist and puts it in the underlying map.-
Methods inherited from class java.util.LinkedHashMap
clear, containsValue, entrySet, forEach, get, getOrDefault, keySet, removeEldestEntry, replaceAll, values
-
Methods inherited from class java.util.HashMap
clone, compute, computeIfAbsent, computeIfPresent, containsKey, isEmpty, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, size
-
Methods inherited from class java.util.AbstractMap
equals, hashCode, toString
-
Methods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface java.util.Map
compute, computeIfAbsent, computeIfPresent, containsKey, equals, hashCode, isEmpty, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, size
-
-
-
-
Constructor Detail
-
MethodConfigMap
protected MethodConfigMap(ApiClassConfig apiClassConfig)
-
MethodConfigMap
protected MethodConfigMap(ApiClassConfig.MethodConfigMap original, ApiClassConfig apiClassConfig)
-
-
Method Detail
-
getOrCreate
public ApiMethodConfig getOrCreate(EndpointMethod method)
Gets the previously createdApiMethodConfiginstance for the given method, or creates a new one if it does not yet exist and puts it in the underlying map. CreatedApiMethodConfigare created with defaults based on the current configuration loaded in the ApiConfig.
-
createMethodConfig
protected ApiMethodConfig createMethodConfig(EndpointMethod method, TypeLoader typeLoader, ApiClassConfig apiClassConfig)
Create the method configuration object. Override to use a subclass instead.
-
getApiClassConfig
public ApiClassConfig getApiClassConfig()
-
-