Class Auth
- java.lang.Object
-
- com.google.api.server.spi.request.Auth
-
public class Auth extends Object
Utilities for end user authentication.
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static AuthenticatorinstantiateAuthenticator(Class<? extends Authenticator> clazz)Must be used to instantiate newAuthenticators to honorSingletoncontract.
-
-
-
Method Detail
-
instantiateAuthenticator
public static Authenticator instantiateAuthenticator(Class<? extends Authenticator> clazz)
Must be used to instantiate newAuthenticators to honorSingletoncontract.- Returns:
- a new instance of clazz, or an existing one if clazz is annotated with @
Singleton
-
-