Interface ParamReader

    • Method Detail

      • read

        Object[] read()
               throws ServiceException
        Reads parameters in JSON into an Object array to be used to invoke an Endpoint method.
        Throws:
        ServiceException - when reading of input stream failed, input JSON is invalid, or cannot be mapped into parameter objects, or user authentication fails.