Class RestServletRequestParamReader

  • All Implemented Interfaces:
    ParamReader

    public class RestServletRequestParamReader
    extends ServletRequestParamReader
    A ParamReader which reads parameters from a JSON-REST request. That is, instead of just looking in the JSON body, it also looks at path and query parameters. This is mainly for use with EndpointsServlet, and tries to emulate existing behavior by stuffing path and query parameters into the main request body.