Class AnnotationApiConfigGenerator

    • Method Detail

      • generateConfig

        public Map<String,​String> generateConfig​(Class<?>... serviceClasses)
                                                throws com.google.api.server.spi.config.ApiConfigException
        Description copied from interface: ApiConfigGenerator
        Generates API configuration file as a string for a set of service classes.
        Specified by:
        generateConfig in interface ApiConfigGenerator
        Parameters:
        serviceClasses - Service classes to generate API configuration for.
        Returns:
        A map of API configuration JSON strings with <apiString>.<ext> as the key.
        Throws:
        com.google.api.server.spi.config.ApiConfigException
      • generateConfig

        public Map<String,​String> generateConfig​(com.google.api.server.spi.ServiceContext serviceContext,
                                                       Class<?>... serviceClasses)
                                                throws com.google.api.server.spi.config.ApiConfigException
        Description copied from interface: ApiConfigGenerator
        Generates API configuration file as a string for a set of service classes given a default API name.
        Specified by:
        generateConfig in interface ApiConfigGenerator
        Parameters:
        serviceContext - Service context used to retrieve information about the service.
        serviceClasses - Service classes to generate API configuration for.
        Returns:
        A map of API configuration JSON strings with <apiString>.<ext> as the key.
        Throws:
        com.google.api.server.spi.config.ApiConfigException