Interface ApiConfigGenerator

    • Method Detail

      • generateConfig

        Map<String,​String> generateConfig​(Class<?>... serviceClasses)
                                         throws IOException,
                                                com.google.api.server.spi.config.ApiConfigException
        Generates API configuration file as a string for a set of service classes.
        Parameters:
        serviceClasses - Service classes to generate API configuration for.
        Returns:
        A map of API configuration JSON strings with <apiString>.<ext> as the key.
        Throws:
        IOException
        com.google.api.server.spi.config.ApiConfigException
      • generateConfig

        Map<String,​String> generateConfig​(com.google.api.server.spi.ServiceContext serviceContext,
                                                Class<?>... serviceClasses)
                                         throws IOException,
                                                com.google.api.server.spi.config.ApiConfigException
        Generates API configuration file as a string for a set of service classes given a default API name.
        Parameters:
        serviceContext - Service context used to retrieve information about the service.
        serviceClasses - Service classes to generate API configuration for.
        Returns:
        A map of API configuration JSON strings with <apiString>.<ext> as the key.
        Throws:
        IOException
        com.google.api.server.spi.config.ApiConfigException