Package com.google.api.server.spi.tools
Interface ClientLibGenerator
-
- All Known Implementing Classes:
CloudClientLibGenerator,FakeClientLibGenerator
public interface ClientLibGeneratorClient library generator.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidgenerateClientLib(String discoveryDoc, String language, String languageVersion, String layout, File file)Generates the client library for an API and saves it in a file.
-
-
-
Method Detail
-
generateClientLib
void generateClientLib(String discoveryDoc, String language, String languageVersion, String layout, File file) throws IOException
Generates the client library for an API and saves it in a file.- Parameters:
discoveryDoc- Discovery document of the APIlanguage- Language of the client library, valid options can be found at https://developers.google.com/resources/api-libraries/endpoints/genliblanguageVersion- Version of language.nullfor default.layout- of the client bundle.nullfor default.file- Zip/jar file to save the generated source into- Throws:
IOException
-
-