Class GenClientLibAction


  • public class GenClientLibAction
    extends EndpointsToolAction
    Command to generated a client library from a Discovery document.
    • Constructor Detail

      • GenClientLibAction

        public GenClientLibAction()
    • Method Detail

      • genClientLibFromFile

        public Object genClientLibFromFile​(String language,
                                           String outputDirPath,
                                           String discoveryDocPath,
                                           String buildSystem)
                                    throws IOException
        Generates a client library for an API.
        Parameters:
        language - Language of the client library.
        outputDirPath - Directory to write generated client library into
        discoveryDocPath - Path to Discovery doc file
        buildSystem - The build system to use for the client library
        Throws:
        IOException
      • genClientLib

        public Object genClientLib​(String language,
                                   String outputDirPath,
                                   String discoveryDoc,
                                   String buildSystem)
                            throws IOException
        Generates a client library for an API.
        Parameters:
        language - Language of the client library.
        outputDirPath - Directory to write generated client library into
        discoveryDoc - Discovery doc text.
        buildSystem - The build system to use for the client library
        Throws:
        IOException