Class GetClientLibAction


  • public class GetClientLibAction
    extends EndpointsToolAction
    Command that combines 3 other ones and generates client libraries from service classes.
    • Constructor Detail

      • GetClientLibAction

        public GetClientLibAction()
    • Method Detail

      • getClientLib

        public Object getClientLib​(URL[] classPath,
                                   String language,
                                   String outputDirPath,
                                   List<String> serviceClassNames,
                                   String buildSystem,
                                   String hostname,
                                   String basePath,
                                   boolean debug)
                            throws ClassNotFoundException,
                                   IOException,
                                   com.google.api.server.spi.config.ApiConfigException
        Generates a Java client library for an API. Combines the steps of generating API configuration, generating Discovery doc and generating client library into one.
        Parameters:
        classPath - Class path to load service classes and their dependencies
        language - Language of the client library. Only "java" is supported right now
        outputDirPath - Directory to write output files into
        serviceClassNames - Array of service class names of the API
        buildSystem - The build system to use for the client library
        hostname - The hostname to use
        basePath - The base path to use
        debug - Whether or not to output intermediate output files
        Throws:
        ClassNotFoundException
        IOException
        com.google.api.server.spi.config.ApiConfigException