Class FakeClientLibGenerator
- java.lang.Object
-
- com.google.api.server.spi.tools.testing.FakeClientLibGenerator
-
- All Implemented Interfaces:
ClientLibGenerator
public class FakeClientLibGenerator extends Object implements ClientLibGenerator
Generates a client library for any discovery document by loading a static jar file.
-
-
Constructor Summary
Constructors Constructor Description FakeClientLibGenerator()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidgenerateClientLib(String discoveryDoc, String language, String languageVersion, String layout, File file)Generates the client library for an API and saves it in a file.
-
-
-
Method Detail
-
generateClientLib
public void generateClientLib(String discoveryDoc, String language, String languageVersion, String layout, File file) throws IOException
Description copied from interface:ClientLibGeneratorGenerates the client library for an API and saves it in a file.- Specified by:
generateClientLibin interfaceClientLibGenerator- Parameters:
discoveryDoc- Discovery document of the APIlanguage- Language of the client library, valid options can be found at https://developers.google.com/resources/api-libraries/endpoints/genliblanguageVersion- Version of language.nullfor default.layout- of the client bundle.nullfor default.file- Zip/jar file to save the generated source into- Throws:
IOException
-
-