Class RpcMethod

  • All Implemented Interfaces:
    Cloneable, Map<String,​Object>

    public final class RpcMethod
    extends com.google.api.client.json.GenericJson
    Model definition for RpcMethod.

    This is the Java data model class that specifies how to parse/serialize into the JSON that is transmitted over HTTP when working with the APIs Discovery Service. For a detailed explanation see: http://code.google.com/p/google-http-java-client/wiki/JSON

    Author:
    Google, Inc.
    • Constructor Detail

      • RpcMethod

        public RpcMethod()
    • Method Detail

      • getAllowGet

        public Boolean getAllowGet()
        Whether the method can be made using an HTTP GET JSON-RPC request.
        Returns:
        value or null for none
      • setAllowGet

        public RpcMethod setAllowGet​(Boolean allowGet)
        Whether the method can be made using an HTTP GET JSON-RPC request.
        Parameters:
        allowGet - allowGet or null for none
      • getDescription

        public String getDescription()
        Description of this method.
        Returns:
        value or null for none
      • setDescription

        public RpcMethod setDescription​(String description)
        Description of this method.
        Parameters:
        description - description or null for none
      • getEtagRequired

        public Boolean getEtagRequired()
        Does this method require sending the ETag along with the request.
        Returns:
        value or null for none
      • setEtagRequired

        public RpcMethod setEtagRequired​(Boolean etagRequired)
        Does this method require sending the ETag along with the request.
        Parameters:
        etagRequired - etagRequired or null for none
      • getId

        public String getId()
        A unique ID for this method. This property can be used to match methods between different versions of Discovery.
        Returns:
        value or null for none
      • setId

        public RpcMethod setId​(String id)
        A unique ID for this method. This property can be used to match methods between different versions of Discovery.
        Parameters:
        id - id or null for none
      • getMediaUpload

        public RpcMethod.MediaUpload getMediaUpload()
        Media upload parameters.
        Returns:
        value or null for none
      • setMediaUpload

        public RpcMethod setMediaUpload​(RpcMethod.MediaUpload mediaUpload)
        Media upload parameters.
        Parameters:
        mediaUpload - mediaUpload or null for none
      • getParameterOrder

        public List<String> getParameterOrder()
        Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures. The array is ordered such that the "most-significant" parameter appears first.
        Returns:
        value or null for none
      • setParameterOrder

        public RpcMethod setParameterOrder​(List<String> parameterOrder)
        Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures. The array is ordered such that the "most-significant" parameter appears first.
        Parameters:
        parameterOrder - parameterOrder or null for none
      • getParameters

        public Map<String,​JsonSchema> getParameters()
        Description for all parameters in this method.
        Returns:
        value or null for none
      • setParameters

        public RpcMethod setParameters​(Map<String,​JsonSchema> parameters)
        Description for all parameters in this method.
        Parameters:
        parameters - parameters or null for none
      • getReturns

        public RpcMethod.Returns getReturns()
        The schema for the response.
        Returns:
        value or null for none
      • setReturns

        public RpcMethod setReturns​(RpcMethod.Returns returns)
        The schema for the response.
        Parameters:
        returns - returns or null for none
      • getScopes

        public List<String> getScopes()
        OAuth 2.0 scopes applicable to this method.
        Returns:
        value or null for none
      • setScopes

        public RpcMethod setScopes​(List<String> scopes)
        OAuth 2.0 scopes applicable to this method.
        Parameters:
        scopes - scopes or null for none
      • getSupportsMediaDownload

        public Boolean getSupportsMediaDownload()
        Whether this method supports media download.
        Returns:
        value or null for none
      • setSupportsMediaDownload

        public RpcMethod setSupportsMediaDownload​(Boolean supportsMediaDownload)
        Whether this method supports media download.
        Parameters:
        supportsMediaDownload - supportsMediaDownload or null for none
      • getSupportsMediaUpload

        public Boolean getSupportsMediaUpload()
        Whether this method supports media upload.
        Returns:
        value or null for none
      • setSupportsMediaUpload

        public RpcMethod setSupportsMediaUpload​(Boolean supportsMediaUpload)
        Whether this method supports media upload.
        Parameters:
        supportsMediaUpload - supportsMediaUpload or null for none
      • getSupportsPatch

        public Boolean getSupportsPatch()
        Whether this method supports patch semantics.
        Returns:
        value or null for none
      • setSupportsPatch

        public RpcMethod setSupportsPatch​(Boolean supportsPatch)
        Whether this method supports patch semantics.
        Parameters:
        supportsPatch - supportsPatch or null for none
      • getSupportsSubscription

        public Boolean getSupportsSubscription()
        Whether this method supports subscriptions.
        Returns:
        value or null for none
      • setSupportsSubscription

        public RpcMethod setSupportsSubscription​(Boolean supportsSubscription)
        Whether this method supports subscriptions.
        Parameters:
        supportsSubscription - supportsSubscription or null for none
      • getUseMediaDownloadService

        public Boolean getUseMediaDownloadService()
        Indicates that downloads from this method should use the download service URL (i.e. "/download"). Only applies if the method supports media download.
        Returns:
        value or null for none
      • setUseMediaDownloadService

        public RpcMethod setUseMediaDownloadService​(Boolean useMediaDownloadService)
        Indicates that downloads from this method should use the download service URL (i.e. "/download"). Only applies if the method supports media download.
        Parameters:
        useMediaDownloadService - useMediaDownloadService or null for none
      • set

        public RpcMethod set​(String fieldName,
                             Object value)
        Overrides:
        set in class com.google.api.client.json.GenericJson
      • clone

        public RpcMethod clone()
        Overrides:
        clone in class com.google.api.client.json.GenericJson