RestMethod |
RestMethod.clone() |
|
RestMethod |
RestMethod.set(String fieldName,
Object value) |
|
RestMethod |
RestMethod.setDescription(String description) |
Description of this method.
|
RestMethod |
RestMethod.setEtagRequired(Boolean etagRequired) |
Whether this method requires an ETag to be specified.
|
RestMethod |
RestMethod.setHttpMethod(String httpMethod) |
HTTP method used by this method.
|
RestMethod |
RestMethod.setId(String id) |
A unique ID for this method.
|
RestMethod |
RestMethod.setMediaUpload(RestMethod.MediaUpload mediaUpload) |
Media upload parameters.
|
RestMethod |
RestMethod.setParameterOrder(List<String> parameterOrder) |
Ordered list of required parameters, serves as a hint to clients on how to structure their
method signatures.
|
RestMethod |
RestMethod.setParameters(Map<String,JsonSchema> parameters) |
Details for all parameters in this method.
|
RestMethod |
RestMethod.setPath(String path) |
The URI path of this REST method.
|
RestMethod |
RestMethod.setRequest(RestMethod.Request request) |
The schema for the request.
|
RestMethod |
RestMethod.setResponse(RestMethod.Response response) |
The schema for the response.
|
RestMethod |
RestMethod.setScopes(List<String> scopes) |
OAuth 2.0 scopes applicable to this method.
|
RestMethod |
RestMethod.setSupportsMediaDownload(Boolean supportsMediaDownload) |
Whether this method supports media downloads.
|
RestMethod |
RestMethod.setSupportsMediaUpload(Boolean supportsMediaUpload) |
Whether this method supports media uploads.
|
RestMethod |
RestMethod.setSupportsSubscription(Boolean supportsSubscription) |
Whether this method supports subscriptions.
|
RestMethod |
RestMethod.setUseMediaDownloadService(Boolean useMediaDownloadService) |
Indicates that downloads from this method should use the download service URL (i.e.
|