Package com.google.api.server.spi
Class EndpointMethod.ResolvedSignature
- java.lang.Object
-
- com.google.api.server.spi.EndpointMethod.ResolvedSignature
-
- Enclosing class:
- EndpointMethod
public class EndpointMethod.ResolvedSignature extends Object
Adapter class to compareEndpointMethodinstances based on their Java method signature rather than the actual method implementation. Comparisons are based on resolved types.This is a pure adapter class containing no state of its own, relying entirely on the state of the owning
EndpointMethodobject. All access to the owning object is made through qualified this calls to make dependencies as clear as possible.
-
-
Constructor Summary
Constructors Constructor Description ResolvedSignature()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object o)StringgetSignatureName()Class<?>[]getSignatureParameterClasses()inthashCode()StringtoString()
-