Interface ParamReader
-
- All Known Implementing Classes:
AbstractParamReader,RestServletRequestParamReader,ServletRequestParamReader
public interface ParamReaderReads a request and returns an array of parameter values.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description Object[]read()Reads parameters in JSON into an Object array to be used to invoke an Endpoint method.
-
-
-
Method Detail
-
read
Object[] read() throws ServiceException
Reads parameters in JSON into an Object array to be used to invoke an Endpoint method.- Throws:
ServiceException- when reading of input stream failed, input JSON is invalid, or cannot be mapped into parameter objects, or user authentication fails.
-
-