Package com.google.api.server.spi.tools
Interface ApiConfigGenerator
-
- All Known Implementing Classes:
AnnotationApiConfigGenerator,FakeApiConfigGenerator
public interface ApiConfigGeneratorAPI configuration generator.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description Map<String,String>generateConfig(com.google.api.server.spi.ServiceContext serviceContext, Class<?>... serviceClasses)Generates API configuration file as a string for a set of service classes given a default API name.Map<String,String>generateConfig(Class<?>... serviceClasses)Generates API configuration file as a string for a set of service classes.
-
-
-
Method Detail
-
generateConfig
Map<String,String> generateConfig(Class<?>... serviceClasses) throws IOException, com.google.api.server.spi.config.ApiConfigException
Generates API configuration file as a string for a set of service classes.- Parameters:
serviceClasses- Service classes to generate API configuration for.- Returns:
- A map of API configuration JSON strings with <apiString>.<ext> as the key.
- Throws:
IOExceptioncom.google.api.server.spi.config.ApiConfigException
-
generateConfig
Map<String,String> generateConfig(com.google.api.server.spi.ServiceContext serviceContext, Class<?>... serviceClasses) throws IOException, com.google.api.server.spi.config.ApiConfigException
Generates API configuration file as a string for a set of service classes given a default API name.- Parameters:
serviceContext- Service context used to retrieve information about the service.serviceClasses- Service classes to generate API configuration for.- Returns:
- A map of API configuration JSON strings with <apiString>.<ext> as the key.
- Throws:
IOExceptioncom.google.api.server.spi.config.ApiConfigException
-
-