Class RpcMethod
- java.lang.Object
-
- java.util.AbstractMap<String,Object>
-
- com.google.api.client.util.GenericData
-
- com.google.api.client.json.GenericJson
-
- com.google.api.services.discovery.model.RpcMethod
-
public final class RpcMethod extends com.google.api.client.json.GenericJsonModel definition for RpcMethod.This is the Java data model class that specifies how to parse/serialize into the JSON that is transmitted over HTTP when working with the APIs Discovery Service. For a detailed explanation see: http://code.google.com/p/google-http-java-client/wiki/JSON
- Author:
- Google, Inc.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classRpcMethod.MediaUploadMedia upload parameters.static classRpcMethod.ReturnsThe schema for the response.-
Nested classes/interfaces inherited from class com.google.api.client.util.GenericData
com.google.api.client.util.GenericData.Flags
-
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object,V extends Object>
-
-
Constructor Summary
Constructors Constructor Description RpcMethod()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description RpcMethodclone()BooleangetAllowGet()Whether the method can be made using an HTTP GET JSON-RPC request.StringgetDescription()Description of this method.BooleangetEtagRequired()Does this method require sending the ETag along with the request.StringgetId()A unique ID for this method.RpcMethod.MediaUploadgetMediaUpload()Media upload parameters.List<String>getParameterOrder()Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures.Map<String,JsonSchema>getParameters()Description for all parameters in this method.RpcMethod.ReturnsgetReturns()The schema for the response.List<String>getScopes()OAuth 2.0 scopes applicable to this method.BooleangetSupportsMediaDownload()Whether this method supports media download.BooleangetSupportsMediaUpload()Whether this method supports media upload.BooleangetSupportsPatch()Whether this method supports patch semantics.BooleangetSupportsSubscription()Whether this method supports subscriptions.BooleangetUseMediaDownloadService()Indicates that downloads from this method should use the download service URL (i.e.RpcMethodset(String fieldName, Object value)RpcMethodsetAllowGet(Boolean allowGet)Whether the method can be made using an HTTP GET JSON-RPC request.RpcMethodsetDescription(String description)Description of this method.RpcMethodsetEtagRequired(Boolean etagRequired)Does this method require sending the ETag along with the request.RpcMethodsetId(String id)A unique ID for this method.RpcMethodsetMediaUpload(RpcMethod.MediaUpload mediaUpload)Media upload parameters.RpcMethodsetParameterOrder(List<String> parameterOrder)Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures.RpcMethodsetParameters(Map<String,JsonSchema> parameters)Description for all parameters in this method.RpcMethodsetReturns(RpcMethod.Returns returns)The schema for the response.RpcMethodsetScopes(List<String> scopes)OAuth 2.0 scopes applicable to this method.RpcMethodsetSupportsMediaDownload(Boolean supportsMediaDownload)Whether this method supports media download.RpcMethodsetSupportsMediaUpload(Boolean supportsMediaUpload)Whether this method supports media upload.RpcMethodsetSupportsPatch(Boolean supportsPatch)Whether this method supports patch semantics.RpcMethodsetSupportsSubscription(Boolean supportsSubscription)Whether this method supports subscriptions.RpcMethodsetUseMediaDownloadService(Boolean useMediaDownloadService)Indicates that downloads from this method should use the download service URL (i.e.-
Methods inherited from class com.google.api.client.json.GenericJson
getFactory, setFactory, toPrettyString, toString
-
Methods inherited from class com.google.api.client.util.GenericData
entrySet, equals, get, getClassInfo, getUnknownKeys, hashCode, put, putAll, remove, setUnknownKeys
-
Methods inherited from class java.util.AbstractMap
clear, containsKey, containsValue, isEmpty, keySet, size, values
-
Methods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface java.util.Map
compute, computeIfAbsent, computeIfPresent, forEach, getOrDefault, merge, putIfAbsent, remove, replace, replace, replaceAll
-
-
-
-
Method Detail
-
getAllowGet
public Boolean getAllowGet()
Whether the method can be made using an HTTP GET JSON-RPC request.- Returns:
- value or
nullfor none
-
setAllowGet
public RpcMethod setAllowGet(Boolean allowGet)
Whether the method can be made using an HTTP GET JSON-RPC request.- Parameters:
allowGet- allowGet ornullfor none
-
getDescription
public String getDescription()
Description of this method.- Returns:
- value or
nullfor none
-
setDescription
public RpcMethod setDescription(String description)
Description of this method.- Parameters:
description- description ornullfor none
-
getEtagRequired
public Boolean getEtagRequired()
Does this method require sending the ETag along with the request.- Returns:
- value or
nullfor none
-
setEtagRequired
public RpcMethod setEtagRequired(Boolean etagRequired)
Does this method require sending the ETag along with the request.- Parameters:
etagRequired- etagRequired ornullfor none
-
getId
public String getId()
A unique ID for this method. This property can be used to match methods between different versions of Discovery.- Returns:
- value or
nullfor none
-
setId
public RpcMethod setId(String id)
A unique ID for this method. This property can be used to match methods between different versions of Discovery.- Parameters:
id- id ornullfor none
-
getMediaUpload
public RpcMethod.MediaUpload getMediaUpload()
Media upload parameters.- Returns:
- value or
nullfor none
-
setMediaUpload
public RpcMethod setMediaUpload(RpcMethod.MediaUpload mediaUpload)
Media upload parameters.- Parameters:
mediaUpload- mediaUpload ornullfor none
-
getParameterOrder
public List<String> getParameterOrder()
Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures. The array is ordered such that the "most-significant" parameter appears first.- Returns:
- value or
nullfor none
-
setParameterOrder
public RpcMethod setParameterOrder(List<String> parameterOrder)
Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures. The array is ordered such that the "most-significant" parameter appears first.- Parameters:
parameterOrder- parameterOrder ornullfor none
-
getParameters
public Map<String,JsonSchema> getParameters()
Description for all parameters in this method.- Returns:
- value or
nullfor none
-
setParameters
public RpcMethod setParameters(Map<String,JsonSchema> parameters)
Description for all parameters in this method.- Parameters:
parameters- parameters ornullfor none
-
getReturns
public RpcMethod.Returns getReturns()
The schema for the response.- Returns:
- value or
nullfor none
-
setReturns
public RpcMethod setReturns(RpcMethod.Returns returns)
The schema for the response.- Parameters:
returns- returns ornullfor none
-
getScopes
public List<String> getScopes()
OAuth 2.0 scopes applicable to this method.- Returns:
- value or
nullfor none
-
setScopes
public RpcMethod setScopes(List<String> scopes)
OAuth 2.0 scopes applicable to this method.- Parameters:
scopes- scopes ornullfor none
-
getSupportsMediaDownload
public Boolean getSupportsMediaDownload()
Whether this method supports media download.- Returns:
- value or
nullfor none
-
setSupportsMediaDownload
public RpcMethod setSupportsMediaDownload(Boolean supportsMediaDownload)
Whether this method supports media download.- Parameters:
supportsMediaDownload- supportsMediaDownload ornullfor none
-
getSupportsMediaUpload
public Boolean getSupportsMediaUpload()
Whether this method supports media upload.- Returns:
- value or
nullfor none
-
setSupportsMediaUpload
public RpcMethod setSupportsMediaUpload(Boolean supportsMediaUpload)
Whether this method supports media upload.- Parameters:
supportsMediaUpload- supportsMediaUpload ornullfor none
-
getSupportsPatch
public Boolean getSupportsPatch()
Whether this method supports patch semantics.- Returns:
- value or
nullfor none
-
setSupportsPatch
public RpcMethod setSupportsPatch(Boolean supportsPatch)
Whether this method supports patch semantics.- Parameters:
supportsPatch- supportsPatch ornullfor none
-
getSupportsSubscription
public Boolean getSupportsSubscription()
Whether this method supports subscriptions.- Returns:
- value or
nullfor none
-
setSupportsSubscription
public RpcMethod setSupportsSubscription(Boolean supportsSubscription)
Whether this method supports subscriptions.- Parameters:
supportsSubscription- supportsSubscription ornullfor none
-
getUseMediaDownloadService
public Boolean getUseMediaDownloadService()
Indicates that downloads from this method should use the download service URL (i.e. "/download"). Only applies if the method supports media download.- Returns:
- value or
nullfor none
-
setUseMediaDownloadService
public RpcMethod setUseMediaDownloadService(Boolean useMediaDownloadService)
Indicates that downloads from this method should use the download service URL (i.e. "/download"). Only applies if the method supports media download.- Parameters:
useMediaDownloadService- useMediaDownloadService ornullfor none
-
set
public RpcMethod set(String fieldName, Object value)
- Overrides:
setin classcom.google.api.client.json.GenericJson
-
clone
public RpcMethod clone()
- Overrides:
clonein classcom.google.api.client.json.GenericJson
-
-